==> currents-api-types-0.0.12.tgz: package/common/parsers/queryParams.ts <==
import { z } from 'zod';
import { FIRESTORE_API_GET_LIMIT } from '../../constants';

// for 'get' query params, .or shenanigans
export const firestoreGetLimitParser = z
  .number()
  .int()
  .or(z.string().regex(/^\d+$/).transform(Number))
  .refine((n) => n >= 0, {
    message: 'limit must be a positive number',
  })
  .refine((n) => n <= FIRESTORE_API_GET_LIMIT, {
    message: `limit must be less than ${FIRESTORE_API_GET_LIMIT}`,
  });
// for 'get' query params, .or shenanigans
export const firestoreGetOffsetParser = z
  .number()
  .int()
  .or(z.string().regex(/^\d+$/).transform(Number))
  .refine((n) => n >= 0, {
    message: 'offset must be a positive number',
  });

export const makeLimitParser = <T extends z.ZodType>(parser: T) =>
  z.object({
    limit: parser,
  });

export const makeOffsetParser = <T extends z.ZodType>(parser: T) =>
  z.object({
    offset: parser,
  });

export const makeOffsetLimitParser = <LP extends z.ZodType, OP extends z.ZodType>(limitParser: LP, offsetParser: OP) =>
  makeLimitParser(limitParser).merge(makeOffsetParser(offsetParser));

const firestoreListLimitParser = firestoreGetLimitParser.optional().default(FIRESTORE_API_GET_LIMIT);
const firestoreListOffsetParser = firestoreGetOffsetParser.optional().default(0);
export const firestoreListLimitParamsParser = makeLimitParser(firestoreListLimitParser);
export const firestoreListOffsetParamsParser = makeOffsetParser(firestoreListOffsetParser);

export const firestoreListParamsParser = makeOffsetLimitParser(firestoreListOffsetParser, firestoreListLimitParser);

==> currents-api-types-0.0.19.tgz: package/common/parsers/queryParams.ts <==
import { z } from 'zod';
import { FIRESTORE_API_GET_LIMIT } from '../../constants';

// for 'get' query params, .or shenanigans
export const firestoreGetLimitParser = z
  .number()
  .int()
  .or(z.string().regex(/^\d+$/).transform(Number))
  .refine((n) => n >= 0, {
    message: 'limit must be a positive number',
  })
  .refine((n) => n <= FIRESTORE_API_GET_LIMIT, {
    message: `limit must be less than ${FIRESTORE_API_GET_LIMIT}`,
  });
// for 'get' query params, .or shenanigans
export const firestoreGetOffsetParser = z
  .number()
  .int()
  .or(z.string().regex(/^\d+$/).transform(Number))
  .refine((n) => n >= 0, {
    message: 'offset must be a positive number',
  });

export const makeLimitParser = <T extends z.ZodType>(parser: T) =>
  z.object({
    limit: parser,
  });

export const makeOffsetParser = <T extends z.ZodType>(parser: T) =>
  z.object({
    offset: parser,
  });

export const makeOffsetLimitParser = <LP extends z.ZodType, OP extends z.ZodType>(limitParser: LP, offsetParser: OP) =>
  makeLimitParser(offsetParser).merge(makeOffsetParser(limitParser));

const firestoreListLimitParser = firestoreGetLimitParser.optional().default(FIRESTORE_API_GET_LIMIT);
const firestoreListOffsetParser = firestoreGetOffsetParser.optional().default(0);
export const firestoreListLimitParamsParser = makeLimitParser(firestoreListLimitParser);
export const firestoreListOffsetParamsParser = makeOffsetParser(firestoreListOffsetParser);

// TODO test that limit can't leak over 1000 or to -1
export const firestoreListParamsParser = makeOffsetLimitParser(firestoreListOffsetParser, firestoreListLimitParser);
